<?php
/**
*
* search_synonyms [American English]
*
* @package language
* @version $Id$
* @copyright (c) 2005 phpBB Group, (c) Maël Soucaze
* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License 2.0
*
*/

if (!defined('IN_PHPBB'))
{
	exit;
}

$synonyms = array(
	'abcense'			=> 'absence',
	'abridgement'		=> 'abridgment',
	'accomodate'		=> 'accommodate',
	'acknowledgement'	=> 'acknowledgment',
	'aeroplane'			=> 'airplane',
	'allright'			=> 'alright ',
	'andy'				=> 'andrew',
	'anaemia'			=> 'anemia',
	'anaemic'			=> 'anemic',
	'anaesthesia'		=> 'anesthesia',
	'apologise'			=> 'apologize',
	'archaean'			=> 'archean',
	'archaeology'		=> 'archeology',
	'archaeozoic'		=> 'archeozoic',
	'armour'				=> 'armor',
	'artic'				=> 'arctic',
	'attachement'		=> 'attachment',
	'attendence'		=> 'attendance',

	'barbecue'	=> 'barbeque',
	'behaviour'	=> 'behavior',
	'biassed'	=> 'biased',
	'biol'		=> 'biology',
	'buletin'	=> 'bulletin',

	'calender'	=> 'calendar',
	'canceled'	=> 'cancelled',
	'car'		=> 'automobile',
	'catalogue'	=> 'catalog',
	'caenozoic'	=> 'cenozoic',
	'centre'	=> 'center',
	'cheque'		=> 'check',
	'colour'		=> 'color',
	'comission'	=> 'commission',
	'comittee'	=> 'committee',
	'commitee'	=> 'committee',
	'conceed'	=> 'concede',
	'createing'	=> 'creating',
	'curiculum'	=> 'curriculum',

	'defence'		=> 'defense',
	'develope'		=> 'develop',
	'discription'	=> 'description',
	'dulness'		=> 'dullness',

	'encyclopaedia'	=> 'encyclopedia',
	'enroll'		=> 'enrol',
	'aesthetic'		=> 'esthetic',
	'aetiology'		=> 'etiology',
	'exhorbitant'	=> 'exorbitant',
	'exhuberant'	=> 'exuberant',
	'existance'		=> 'existence',

	'favourite'		=> 'favorite',
	'foetus'			=> 'fetus',
	'ficticious'	=> 'fictitious',
	'flavour'		=> 'flavor',
	'flourescent'	=> 'fluorescent',
	'foriegn'		=> 'foreign',
	'fourty'		=> 'forty',

	'gauge'			=> 'gage',
	'geneology'		=> 'genealogy',
	'grammer'		=> 'grammar',
	'grey'			=> 'gray',
	'guerilla'		=> 'guerrilla',
	'gynaecology'	=> 'gynecology',

	'harbour'		=> 'harbor',
	'heighth'		=> 'height',
	'haemaglobin'	=> 'hemaglobin',
	'haematin'		=> 'hematin',
	'haematite'		=> 'hematite',
	'haematology'	=> 'hematology',
	'honour'			=> 'honor',

	'innoculate'	=> 'inoculate',
	'installment'	=> 'instalment',
	'irrelevent'	=> 'irrelevant',
	'irrevelant'	=> 'irrelevant',

	'jeweller'	=> 'jeweler',
	'judgement'	=> 'judgment',

	'labelled'	=> 'labeled',
	'labour'		=> 'labor',
	'labourer'	=> 'laborer',
	'labourers'	=> 'laborers',
	'labouring'	=> 'laboring',
	'licence'	=> 'license',
	'leisure'	=> 'liesure',
	'liquify'	=> 'liquefy',

	'maintainance'	=> 'maintenance',
	'maintenence'	=> 'maintenance',
	'mediaeval'		=> 'medieval',
	'metre'			=> 'meter',
	'mileage'		=> 'milage',
	'millepede'		=> 'millipede',
	'miscelaneous'	=> 'miscellaneous',
	'morgage'		=> 'mortgage',

	'noticable'	=> 'noticeable',

	'occurence'	=> 'occurrence',
	'offense'	=> 'offence',
	'ommision'	=> 'omission',
	'ommission'	=> 'omission',
	'optimise'	=> 'optimize',
	'organise'	=> 'organize',

	'pyjamas'			=> 'pajamas',
	'palaeography'		=> 'paleography',
	'palaeolithic'		=> 'paleolithic',
	'palaeontological'	=> 'paleontological',
	'palaeontologist'	=> 'paleontologist',
	'palaeontology'		=> 'paleontology',
	'palaeozoic'			=> 'paleozoic',
	'pamplet'			=> 'pamphlet',
	'paralell'			=> 'parallel',
	'parl'				=> 'parliament',
	'parlt'				=> 'parliament',
	'paediatric'			=> 'pediatric',
	'paediatrician'		=> 'pediatrician',
	'paediatrics'		=> 'pediatrics',
	'paedodontia'		=> 'pedodontia',
	'paedodontics'		=> 'pedodontics',
	'personel'			=> 'personnel',
	'practise'			=> 'practice',
	'programme'			=> 'program',
	'psych'				=> 'psychology',

	'questionaire'	=> 'questionnaire',

	'rarify'		=> 'rarefy',
	'reccomend'		=> 'recommend',
	'recieve'		=> 'receive',
	'resistence'	=> 'resistance',
	'restaraunt'	=> 'restaurant',

	'saviour'			=> 'savior',
	'sep'				=> 'september',
	'seperate'			=> 'separate',
	'sept'				=> 'september',
	'sieze'				=> 'seize',
	'summarise'			=> 'summarize',
	'summerise'			=> 'summarize',
	'superceed'			=> 'supercede',
	'superintendant'	=> 'superintendent',
	'supersede'			=> 'supercede',
	'suprise'			=> 'surprise',
	'surprise'			=> 'surprize',
	'synchronize'		=> 'synchronise',

	'temperary'		=> 'temporary',
	'theatre'		=> 'theater',
	'threshhold'	=> 'threshold',
	'transfered'	=> 'transferred',
	'truely'		=> 'truly',
	'truley'		=> 'truly',

	'useable'	=> 'usable',

	'valour'	=> 'valor',
	'vigour'	=> 'vigor',
	'vol'	=> 'volume',

	'whack'		=> 'wack',
	'withold'	=> 'withhold',

	'yeild'	=> 'yield',
);
?>